@@ -62,10 +62,14 @@ def apps_that_inherit(request, fqn):
     return apps
 
 
-def app_by_fqn(request, fqn, catalog=True):
-    apps = api.muranoclient(request).packages.filter(fqn=fqn, catalog=catalog)
+def app_by_fqn(request, fqn, catalog=True, version=None):
+    kwargs = {'fqn': fqn, 'catalog': catalog}
+    glare = getattr(settings, 'MURANO_USE_GLARE', False)
+    if glare and version:
+        kwargs['version'] = version
+    apps = api.muranoclient(request).packages.filter(**kwargs)
     try:
-        return apps.next()
+        return next(apps)
     except StopIteration:
         return None
 
@@ -111,13 +115,14 @@ def get_app_supplier_logo(request, app_id):
     return api.muranoclient(request).packages.get_supplier_logo(app_id)
 
 
-@cache.with_cache('package_fqn')
 def get_app_fqn(request, app_id):
-    package = api.muranoclient(request).packages.get(app_id)
-    return package.fully_qualified_name
+    return get_package_details(request, app_id).fully_qualified_name
 
 
-@cache.with_cache('package_name')
 def get_service_name(request, app_id):
-    package = api.muranoclient(request).packages.get(app_id)
-    return package.name
+    return get_package_details(request, app_id).name
+
+
+@cache.with_cache('package_details')
+def get_package_details(request, app_id):
+    return api.muranoclient(request).packages.get(app_id)
