@@ -19,15 +19,39 @@ except ImportError:
 import bs4
 import string
 
+import iso8601
 from muranodashboard.dynamic_ui import yaql_expression
-import six
+import pytz
 import yaql
 
+from django.template import Context
+
+from horizon.utils import functions as utils
+
+# WrappingColumn is only available in N-horizon
+# This make murano-dashboard compatible with Mitaka-horizon
+try:
+    from horizon.tables import WrappingColumn as Column
+except ImportError:
+    from horizon.tables import Column as Column  # noqa
+
+
+REQUIRED_CONTEXT_ATTRIBTUES = (
+    '_form_config',
+    '_form_render',
+)
+
+
+# We need a custom subclass of dict here in order to allow setting attributes
+# on it like _form_config and _form_render.
+class DictContext(dict):
+    pass
+
 
 def parse_api_error(api_error_html):
-    error_html = bs4.BeautifulSoup(api_error_html)
+    error_html = bs4.BeautifulSoup(api_error_html, "html.parser")
     body = error_html.find('body')
-    if not body:
+    if (not body or not body.text):
         return None
     h1 = body.find('h1')
     if h1:
@@ -40,6 +64,12 @@ def ensure_python_obj(obj):
     return mappings.get(obj, obj)
 
 
+def adjust_datestr(request, datestr):
+    tz = pytz.timezone(utils.get_timezone(request))
+    dt = iso8601.parse_date(datestr).astimezone(tz)
+    return dt.strftime('%Y-%m-%d %H:%M:%S')
+
+
 class Bunch(object):
     """Bunch dict/object-like container.
 
@@ -47,7 +77,7 @@ class Bunch(object):
     object-like attribute access.
     """
     def __init__(self, **kwargs):
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             setattr(self, key, value)
 
     def __getitem__(self, item):
@@ -63,7 +93,7 @@ class Bunch(object):
         return hasattr(self, item)
 
     def __iter__(self):
-        return iter(six.itervalues(self.__dict__))
+        return iter(self.__dict__.values())
 
 
 class BlankFormatter(string.Formatter):
@@ -107,10 +137,31 @@ class CustomUnpickler(object):
         unpickler = pickle.Unpickler(file)
         unpickler.persistent_load = self.persistent_load
         self.load = unpickler.load
-        self.noload = unpickler.noload
+        self.noload = getattr(unpickler, 'noload', None)
 
     def persistent_load(self, obj_id):
         if obj_id == 'filtered:YaqlEngine':
             return yaql_expression.YAQL
         else:
             raise pickle.UnpicklingError('Invalid persistent id')
+
+
+def flatten_context(context):
+    if isinstance(context, Context):
+        flat = {}
+        for d in context.dicts:
+            flat.update(d)
+        return flat
+    else:
+        return context
+
+
+def flatten_contexts(*contexts):
+    new_context = DictContext()
+    for context in contexts:
+        if context is not None:
+            new_context.update(flatten_context(context))
+            for attr in REQUIRED_CONTEXT_ATTRIBTUES:
+                if hasattr(context, attr):
+                    setattr(new_context, attr, getattr(context, attr))
+    return new_context
