@@ -28,13 +28,15 @@ from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms as hz_forms
 from horizon import messages
+try:
+    from openstack_dashboard.api import _nova as nova
+except ImportError:
+    from openstack_dashboard.api import nova
 from openstack_dashboard.api import cinder
 from openstack_dashboard.api import glance
 from openstack_dashboard.api import neutron
-from openstack_dashboard.api import nova
 from oslo_log import log as logging
 from oslo_log import versionutils
-import six
 from yaql import legacy
 
 from muranodashboard.api import packages as pkg_api
@@ -54,7 +56,7 @@ def with_request(func):
     """
     def update(self, initial, request=None, **kwargs):
         initial_request = initial.get('request')
-        for key, value in six.iteritems(initial):
+        for key, value in iter(initial.items()):
             if key != 'request' and key not in kwargs:
                 kwargs[key] = value
 
@@ -251,8 +253,8 @@ class CharField(forms.CharField, CustomPropertiesField):
 
 
 class PasswordField(CharField):
-    special_characters = '!@#$%^&*()_+|\/.,~?><:{}-'
-    password_re = re.compile('^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
+    special_characters = '!@#$%^&*()_+|\\/.,~?><:{}-'
+    password_re = re.compile(r'^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
                              % special_characters)
     has_clone = False
     original = True
@@ -437,6 +439,9 @@ class KeyPairChoiceField(DynamicChoiceField):
         for keypair in sorted(keypairs, key=lambda e: e.name):
             self.choices.append((keypair.name, keypair.name))
 
+        if len(keypairs) == 1:
+            self.initial = keypairs[0].name
+
 
 class SecurityGroupChoiceField(DynamicChoiceField):
     """This widget allows to select a security group for VMs"""
@@ -495,11 +500,14 @@ class ImageChoiceField(ChoiceField):
                     continue
             image_map[image.id] = title
 
-        for id_, title in sorted(six.iteritems(image_map),
+        for id_, title in sorted(iter(image_map.items()),
                                  key=lambda e: e[1].title):
             image_choices.append((id_, title))
+
         if image_choices:
-            image_choices.insert(0, ("", _("Select Image")))
+            # If only one choice, select it as only option
+            if len(image_choices) != 1:
+                image_choices.insert(0, ("", _("Select Image")))
         else:
             image_choices.insert(0, ("", _("No images available")))
 
@@ -561,7 +569,8 @@ class AZoneChoiceField(ChoiceField):
                               _("Unable to retrieve  availability zones."))
 
         az_choices = [(az.zoneName, az.zoneName)
-                      for az in availability_zones if az.zoneState]
+                      for az in availability_zones
+                      if az.zoneState['available']]
         if not az_choices:
             az_choices.insert(0, ("", _("No availability zones available")))
 
