@@ -19,9 +19,9 @@ import semantic_version
 from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 from oslo_log import log as logging
-import six
 from yaql import legacy
 
+from muranodashboard import api
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.catalog import forms as catalog_forms
 from muranodashboard.dynamic_ui import helpers
@@ -40,9 +40,6 @@ LOG.info('Using cache directory located at {dir}'.format(
     dir=consts.CACHE_DIR))
 
 
-_apps = {}
-
-
 class Service(object):
     """Murano Service representation object
 
@@ -59,10 +56,12 @@ class Service(object):
     stored at local file-system cache .
     """
     def __init__(self, cleaned_data, version, fqn, forms=None, templates=None,
-                 application=None, **kwargs):
+                 application=None, parameters=None, **kwargs):
         self.cleaned_data = cleaned_data
         self.templates = templates or {}
         self.spec_version = str(version)
+        if forms is None:
+            forms = []
 
         if application is None:
             raise ValueError('Application section is required')
@@ -70,18 +69,29 @@ class Service(object):
             self.application = application
 
         self.context = legacy.create_context()
+        self.context['?service'] = self
         yaql_functions.register(self.context)
 
+        params = parameters or {}
+        self.parameters = {}
+        for k, v in params.items():
+            if not k or not k[0].isalpha():
+                continue
+            v = helpers.evaluate(v, self.context)
+            self.parameters[k] = v
+            self.context[k] = v
+
         self.forms = []
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             setattr(self, key, value)
 
         for form in forms:
-            name, field_specs, validators = self.extract_form_data(form)
+            (name, field_specs, validators,
+             region) = self.extract_form_data(form)
             # NOTE(kzaitsev) should be str (not unicode) under python2
             # however it also works as str under python3
             name = helpers.to_str(name)
-            self._add_form(name, field_specs, validators)
+            self._add_form(name, field_specs, validators, region)
 
         # Add ManageWorkflowForm
         workflow_form = catalog_forms.WorkflowManagementForm()
@@ -94,35 +104,40 @@ class Service(object):
                        workflow_form.field_specs,
                        workflow_form.validators)
 
-    def _add_form(self, _name, _specs, _validators, _verbose_name=None):
+    def _add_form(self, _name, _specs, _validators, _verbose_name=None,
+                  _region=None):
         import muranodashboard.dynamic_ui.forms as forms
 
-        class Form(six.with_metaclass(forms.DynamicFormMetaclass,
-                   forms.ServiceConfigurationForm)):
+        class Form(forms.ServiceConfigurationForm,
+                   metaclass=forms.DynamicFormMetaclass):
             service = self
             name = _name
             verbose_name = _verbose_name
             field_specs = _specs
             validators = _validators
+            region = _region
 
         self.forms.append(Form)
 
     @staticmethod
     def extract_form_data(data):
-        for form_name, form_data in six.iteritems(data):
-            return form_name, form_data['fields'], form_data.get('validators',
-                                                                 [])
+        for form_name, form_data in data.items():
+            return (form_name, form_data['fields'],
+                    form_data.get('validators', []), form_data.get('region'))
 
     def extract_attributes(self):
-        self.context['$'] = self.cleaned_data
-        for name, template in six.iteritems(self.templates):
-            self.context[name] = template
+        context = self.context.create_child_context()
+        context['$'] = self.cleaned_data
+        context['$forms'] = self.cleaned_data
+
+        for name, template in self.templates.items():
+            context[name] = template
         if semantic_version.Version.coerce(self.spec_version) \
                 >= semantic_version.Version.coerce('2.2'):
             management_form = catalog_forms.WF_MANAGEMENT_NAME
-            name = self.context['$'][management_form]['application_name']
+            name = self.cleaned_data[management_form]['application_name']
             self.application['?']['name'] = name
-        attributes = helpers.evaluate(self.application, self.context)
+        attributes = helpers.evaluate(self.application, context)
         return attributes
 
     def get_data(self, form_name, expr, data=None):
@@ -130,8 +145,7 @@ class Service(object):
         if data:
             self.update_cleaned_data(data, form_name=form_name)
         data = self.cleaned_data
-        value = data and expr.evaluate(data=data, context=self.context)
-        return data != {}, value
+        return expr.evaluate(data=data, context=self.context)
 
     def update_cleaned_data(self, data, form=None, form_name=None):
         form_name = form_name or form.__class__.__name__
@@ -156,17 +170,36 @@ def import_app(request, app_id):
     app_version = ui_desc.pop('Version', version.LATEST_FORMAT_VERSION)
     version.check_version(app_version)
     service = dict(
-        (helpers.decamelize(k), v) for (k, v) in six.iteritems(ui_desc))
+        (helpers.decamelize(k), v) for (k, v) in ui_desc.items())
+    parameters = service.pop('parameters', {})
+    parameters_source = service.pop('parameters_source', None)
+    if parameters_source is not None:
+        parts = parameters_source.rsplit('.', 1)
+        if 2 >= len(parts) > 0:
+            if len(parts) == 2:
+                class_name, method_name = parts
+            else:
+                method_name = parts[0]
+                class_name = service.get('application', {}).get('?', {}).get(
+                    'type', fqn)
 
-    global _apps  # In-memory caching of dynamic UI forms
-    if app_id in _apps:
-        LOG.debug('Using in-memory forms for app {0}'.format(fqn))
-        app = _apps[app_id]
-        app.set_data(app_data)
-    else:
-        LOG.debug('Creating new forms for app {0}'.format(fqn))
-        app = _apps[app_id] = Service(app_data, app_version, fqn, **service)
-    return app
+            details = pkg_api.get_package_details(request, app_id)
+            pkg_version = getattr(details, 'version', '*')
+            request_body = {
+                'className': class_name,
+                'methodName': method_name,
+                'packageName': fqn,
+                'classVersion': pkg_version,
+                'parameters': {}
+            }
+
+            result = api.muranoclient(request).static_actions.call(
+                request_body).get_result()
+            if result and isinstance(result, dict):
+                parameters.update(result)
+
+    return Service(app_data, app_version, fqn, parameters=parameters,
+                   **service)
 
 
 def condition_getter(request, kwargs):
@@ -226,7 +259,7 @@ def get_app_forms(request, kwargs):
         return _get_form_name(i, form, _('Step {0}'))
 
     step_names = [get_form_name(*pair) for pair in enumerate(app.forms)]
-    return zip(step_names, app.forms)
+    return list(zip(step_names, app.forms))
 
 
 def service_type_from_id(service_id):
@@ -243,7 +276,7 @@ def get_app_field_descriptions(request, app_id, index):
     form_cls = app.forms[index]
     descriptions = []
     no_field_descriptions = []
-    for name, field in six.iteritems(form_cls.base_fields):
+    for name, field in form_cls.base_fields.items():
         title = field.description_title
         description = field.description
         if description:
