@@ -15,11 +15,12 @@
 import base64
 import json
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
 from django import http
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.views import generic
+from horizon import conf
 from horizon import exceptions
 from horizon.forms import views
 from horizon import tables
@@ -44,12 +45,12 @@ class IndexView(tables.DataTableView):
             environments = api.environments_list(self.request)
         except exc.CommunicationError:
             exceptions.handle(self.request,
-                              'Could not connect to Murano API \
-                              Service, check connection details')
+                              'Could not connect to Murano API '
+                              'Service, check connection details')
         except exc.HTTPInternalServerError:
             exceptions.handle(self.request,
-                              'Murano API Service is not responding. \
-                              Try again later')
+                              'Murano API Service is not responding. '
+                              'Try again later')
         except exc.HTTPUnauthorized:
             exceptions.handle(self.request, ignore=True, escalate=True)
 
@@ -68,17 +69,32 @@ class EnvironmentDetails(tabs.TabbedTableView):
             self.environment_id = self.kwargs['environment_id']
             env = api.environment_get(self.request, self.environment_id)
             context['environment_name'] = env.name
-
         except Exception:
             msg = _("Sorry, this environment doesn't exist anymore")
             redirect = self.get_redirect_url()
             exceptions.handle(self.request, msg, redirect=redirect)
+            return context
         context['tenant_id'] = self.request.session['token'].tenant['id']
         context["url"] = self.get_redirect_url()
+        table = env_tables.EnvironmentsTable(self.request)
+        # record the origin row_action for EnvironmentsTable Meta
+        ori_row_actions = table._meta.row_actions
+        # remove the duplicate 'Manage Components' and 'DeployEnvironment'
+        # actions that have already in Environment Details page
+        # from table.render_row_actions, so the action render to the detail
+        # page will exclude those two actions.
+        table._meta.row_actions = filter(
+            lambda x: x.name not in ('show', 'deploy'),
+            table._meta.row_actions)
+        context["actions"] = table.render_row_actions(env)
+        # recover the origin row_action for EnvironmentsTable Meta
+        table._meta.row_actions = ori_row_actions
+        context['poll_interval'] = conf.HORIZON_CONFIG['ajax_poll_interval']
         return context
 
     def get_tabs(self, request, *args, **kwargs):
         environment_id = self.kwargs['environment_id']
+        deployments = []
         try:
             deployments = api.deployments_list(self.request,
                                                environment_id)
@@ -99,7 +115,7 @@ class EnvironmentDetails(tabs.TabbedTableView):
 
     @staticmethod
     def get_redirect_url():
-        return reverse_lazy("horizon:murano:environments:index")
+        return reverse_lazy("horizon:app-catalog:environments:index")
 
 
 class DetailServiceView(tabs.TabbedTableView):
@@ -115,11 +131,10 @@ class DetailServiceView(tabs.TabbedTableView):
         env = api.environment_get(self.request, self.environment_id)
         context["environment_name"] = env.name
         breadcrumb = [
-            (_("Environments"), EnvironmentDetails.get_redirect_url()),
             (context["environment_name"],
-             reverse("horizon:murano:environments:services",
+             reverse("horizon:app-catalog:environments:services",
                      args=[self.environment_id])),
-            (_('Applications'),), ]
+            (_('Applications'), None)]
         context["custom_breadcrumb"] = breadcrumb
         return context
 
@@ -134,7 +149,7 @@ class DetailServiceView(tabs.TabbedTableView):
             exceptions.handle(self.request)
 
         except exc.HTTPForbidden:
-            redirect = reverse('horizon:murano:environments:index')
+            redirect = reverse('horizon:app-catalog:environments:index')
             exceptions.handle(self.request,
                               _('Unable to retrieve details for '
                                 'service'),
@@ -156,11 +171,13 @@ class CreateEnvironmentView(views.ModalFormView):
     page_title = _('Create Environment')
     context_object_name = 'environment'
     submit_label = _('Create')
-    submit_url = reverse_lazy('horizon:murano:environments:create_environment')
+    submit_url = reverse_lazy(
+        'horizon:app-catalog:environments:create_environment')
 
-    def get_form(self, form_class):
+    def get_form(self, **kwargs):
         if 'next' in self.request.GET:
             self.request.session['next_url'] = self.request.GET['next']
+        form_class = kwargs.get('form_class', self.get_form_class())
         return super(CreateEnvironmentView, self).get_form(form_class)
 
     def get_success_url(self):
@@ -169,9 +186,29 @@ class CreateEnvironmentView(views.ModalFormView):
         env_id = self.request.session.get('env_id')
         if env_id:
             del self.request.session['env_id']
-            return reverse("horizon:murano:environments:services",
+            return reverse("horizon:app-catalog:environments:services",
                            args=[env_id])
-        return reverse_lazy('horizon:murano:environments:index')
+        return reverse_lazy('horizon:app-catalog:environments:index')
+
+
+class DeploymentHistoryView(tables.DataTableView):
+    table_class = env_tables.DeploymentHistoryTable
+    template_name = 'environments/index.html'
+    page_title = _("Deployment History")
+
+    def get_data(self):
+        deployment_history = []
+        try:
+            deployment_history = api.deployment_history(self.request)
+        except exc.HTTPUnauthorized:
+            exceptions.handle(self.request)
+        except exc.HTTPForbidden:
+            redirect = reverse('horizon:app-catalog:environments:services',
+                               args=[self.environment_id])
+            exceptions.handle(self.request,
+                              _('Unable to retrieve deployment history.'),
+                              redirect=redirect)
+        return deployment_history
 
 
 class DeploymentDetailsView(tabs.TabbedTableView):
@@ -190,11 +227,10 @@ class DeploymentDetailsView(tabs.TabbedTableView):
                                      self.environment_id,
                                      self.deployment_id)
         breadcrumb = [
-            (_("Environments"), EnvironmentDetails.get_redirect_url()),
             (context["environment_name"],
-             reverse("horizon:murano:environments:services",
+             reverse("horizon:app-catalog:environments:services",
                      args=[self.environment_id])),
-            (_('Deployments'),), ]
+            (_('Deployments'), None)]
         context["custom_breadcrumb"] = breadcrumb
         return context
 
@@ -206,7 +242,7 @@ class DeploymentDetailsView(tabs.TabbedTableView):
                                                   self.deployment_id)
         except (exc.HTTPInternalServerError, exc.HTTPNotFound):
             msg = _("Deployment with id %s doesn't exist anymore")
-            redirect = reverse("horizon:murano:environments:deployments")
+            redirect = reverse("horizon:app-catalog:environments:deployments")
             exceptions.handle(self.request,
                               msg % self.deployment_id,
                               redirect=redirect)
@@ -220,7 +256,7 @@ class DeploymentDetailsView(tabs.TabbedTableView):
                                           self.deployment_id)
         except (exc.HTTPInternalServerError, exc.HTTPNotFound):
             msg = _('Deployment with id %s doesn\'t exist anymore')
-            redirect = reverse("horizon:murano:environments:deployments")
+            redirect = reverse("horizon:app-catalog:environments:deployments")
             exceptions.handle(self.request,
                               msg % self.deployment_id,
                               redirect=redirect)
@@ -258,7 +294,7 @@ class StartActionView(generic.View):
     def post(request, environment_id, action_id):
         if api.action_allowed(request, environment_id):
             task_id = api.run_action(request, environment_id, action_id)
-            url = reverse('horizon:murano:environments:action_result',
+            url = reverse('horizon:app-catalog:environments:action_result',
                           args=(environment_id, task_id))
             return JSONResponse({'url': url})
         else:
